| aes-coord | R Documentation |
Allow stat layers to receive a sequence of positional variables
rather than only x and y.
aes_coord(.data, prefix)
get_aes_coord(data)
aes_c(...)
.data, data |
A data frame. |
prefix |
A regular expression used to identify the coordinate columns
of |
... |
objects to be concatenated. All |
These functions coordinate (pun intended) the use of more than two positional
variables in plot layers. Pass multidimensional coordinates to a stat via
mapping = aes_coord(...) and reconcile the recovered coordinates with x
and y (which are overridden if present) in Stat*$compute_*(); see the
StatChull source code for an example. Use aes_c() to concatenate
aesthetic mappings.
An S7 object representing a list with class mapping. Components of
the list are either quosures or constants.
ggplot2::aes() for standard ggplot2 aesthetic mappings.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.