View source: R/geom-intervals.r
| geom_lineranges | R Documentation |
geom_lineranges() renders horizontal and vertical intervals
for a specified subject or variable; geom_pointranges() additionally
renders a point at their crosshairs.
geom_lineranges(
mapping = NULL,
data = NULL,
stat = "center",
position = "identity",
...,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
geom_pointranges(
mapping = NULL,
data = NULL,
stat = "center",
position = "identity",
...,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
mapping |
Set of aesthetic mappings created by |
data |
The data to be displayed in this layer. There are three options: If A A |
stat |
The statistical transformation to use on the data for this layer.
When using a
|
position |
A position adjustment to use on the data for this layer. This
can be used in various ways, including to prevent overplotting and
improving the display. The
|
... |
Additional arguments passed to |
na.rm |
Passed to |
show.legend |
logical. Should this layer be included in the legends?
|
inherit.aes |
If |
The geom_*ranges() layers are shortcuts for equivalently-specified
pairs of horizontal and vertical
ggplot2::geom_*range() layers. Rather than
ggplot2::stat_identity(), they default to stat_center(), so that in
practice the summary values do not need to be manually passed.
A ggproto layer.
geom_lineranges() and geom_pointranges() understand the following
aesthetics (required aesthetics are in bold):
x
xmin
xmax
y
ymin
ymax'
alpha
colour
linewidth
linetype
size
group
Other geom layers:
geom_axis(),
geom_bagplot(),
geom_isoline(),
geom_rule(),
geom_text_radiate(),
geom_vector()
ggplot(mpg, aes(x = displ, y = hwy, color = drv)) +
geom_point(alpha = .25) +
geom_lineranges()
if (require(Hmisc)) {
ggplot(mpg, aes(x = displ, y = hwy, color = drv)) +
geom_point(alpha = .25) +
geom_pointranges(fun.data = mean_sdl, shape = "circle open")
}
mpg %>%
aggregate(
x = cbind(displ, hwy) ~ 0,
FUN = function(z) c(min = min(z), med = median(z), max = max(z))
) %>%
do.call(what = data.frame) %>%
ggplot(aes(displ.med, hwy.med)) +
geom_pointranges(
stat = "identity",
aes(xmin = displ.min, xmax = displ.max, ymin = hwy.min, ymax = hwy.max)
) +
geom_point(data = mpg, aes(displ, hwy), alpha = .5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.