View source: R/geom-text-radiate.r
| geom_text_radiate | R Documentation |
geom_text_radiate() is adapted from ggbiplot() in the
off-CRAN extensions of the same name (Vu, 2014; Telford, 2017; Gegzna,
2018). It renders text at specified positions and angles that radiate out
from the origin. This layer and its associated ggproto are deprecated.
geom_text_radiate(
mapping = NULL,
data = NULL,
stat = "identity",
position = "identity",
...,
parse = FALSE,
check_overlap = FALSE,
na.rm = FALSE,
show.legend = NA,
inherit.aes = TRUE
)
mapping |
Set of aesthetic mappings created by |
data |
The data to be displayed in this layer. There are three options: If A A |
stat |
The statistical transformation to use on the data for this layer.
When using a
|
position |
A position adjustment to use on the data for this layer. This
can be used in various ways, including to prevent overplotting and
improving the display. The
|
... |
Other arguments passed on to
|
parse |
If |
check_overlap |
If |
na.rm |
If |
show.legend |
logical. Should this layer be included in the legends?
|
inherit.aes |
If |
A ggproto layer.
geom_text_radiate() understands the following aesthetics (required
aesthetics are in bold):
x
y
label
alpha
angle
colour
family
fontface
hjust
lineheight
size
vjust
group
Vincent Q. Vu (2014). ggbiplot: A 'ggplot2' based biplot. R package version
0.55. https://github.com/vqv/ggbiplot, experimental branch
Richard J Telford (2017). ggbiplot: A 'ggplot2' based biplot. R package
version 0.6. https://github.com/richardjtelford/ggbiplot (fork),
experimental branch
Vilmantas Gegzna (2018). ggbiplot: A 'ggplot2' based biplot. R package
version 0.55. https://github.com/forked-packages/ggbiplot (fork), experimental
branch
Other geom layers:
geom_axis(),
geom_bagplot(),
geom_isoline(),
geom_lineranges(),
geom_rule(),
geom_vector()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.