View source: R/stat-spantree.r
| stat_spantree | R Documentation |
This stat layer identifies the n-1 pairs among n
points that form a minimum spanning tree, then calculates the segments
between these poirs in the two dimensions x and y.
stat_spantree(
mapping = NULL,
data = NULL,
geom = "segment",
position = "identity",
engine = "mlpack",
method = "euclidean",
show.legend = NA,
inherit.aes = TRUE,
...
)
mapping |
Set of aesthetic mappings created by |
data |
The data to be displayed in this layer. There are three options: If A A |
geom |
The geometric object to use to display the data for this layer.
When using a
|
position |
A position adjustment to use on the data for this layer. This
can be used in various ways, including to prevent overplotting and
improving the display. The
|
engine |
A single character string specifying the package implementation
to use; |
method |
Passed to |
show.legend |
logical. Should this layer be included in the legends?
|
inherit.aes |
If |
... |
Additional arguments passed to |
A minimum spanning tree (MST) on the point cloud X is a minimal
connected graph on X with the smallest possible sum of distances (or
dissimilarities) between linked points. These layers call stats::dist() to
calculate a distance/dissimilarity object and an engine from mlpack,
vegan, or ade4 to calculate the MST. The result is formatted with
position aesthetics readable by ggplot2::geom_segment().
An MST calculated on x and y reflects the distances among the points in
X in the reduced-dimension plane of the biplot. In contrast, one
calculated on the full set of coordinates reflects distances in
higher-dimensional space. Plotting this high-dimensional MST on the
2-dimensional biplot provides a visual cue as to how faithfully two
dimensions can encapsulate the "true" distances between points (Jolliffe,
2002).
A ggproto layer.
This statistical transformation is compatible with the convenience function
aes_coord().
Some transformations (e.g. stat_center()) commute with projection to the
lower (1 or 2)-dimensional biplot space. If they detect aesthetics of the
form ..coord[0-9]+, then ..coord1 and ..coord2 are converted to x and
y while any remaining are ignored.
Other transformations (e.g. stat_spantree()) yield different results in a
lower-dimensional biplot when they are computed before versus after
projection. If the stat layer detects these aesthetics, then the
transformation is performed before projection, and the results in the first
two dimensions are returned as x and y.
A small number of transformations (stat_rule()) are incompatible with
these aesthetics but will accept aes_coord() without warning.
These are calculated during the statistical transformation and can be accessed with delayed evaluation.
xend,yend,x,yendpoints of tree branches (segments)
Jolliffe IT (2002) Principal Component Analysis, Second Edition. Springer Series in Statistics, ISSN 0172-7397. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/b98835")} https://link.springer.com/book/10.1007/b98835
Other stat layers:
stat_bagplot(),
stat_center(),
stat_chull(),
stat_cone(),
stat_depth(),
stat_rule(),
stat_scale()
eurodist %>%
cmdscale(k = 6) %>%
as.data.frame() %>%
tibble::rownames_to_column(var = "city") ->
euro_mds
ggplot(euro_mds, aes(V1, V2, label = city)) +
stat_spantree() +
geom_label(alpha = .25)
ggplot(euro_mds, aes_c(aes_coord(euro_mds, "V"), aes(label = city))) +
stat_spantree() +
geom_label(aes(x = V1, y = V2), alpha = .25)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.