These key drawing functions supplement those built into ggplot2 for legend glyphs suitable to bivariate line-ranges and point-ranges.
draw_key_line(data, params, size)draw_key_crosslines(data, params, size)
draw_key_crosspoint(data, params, size)
A grid grob.
A single row data frame containing the scaled aesthetics to display in this key
A list of additional parameters supplied to the geom.
Width and height of key in mm.
draw_key_line() is a horizontal counterpart to ggplot2::draw_key_vline().
draw_key_crosslines() superimposes these two keys, and
draw_key_crosspoint() additionally superimposes an oversized
ggplot2::draw_key_point().
ggplot2::draw_key for key glyphs installed with ggplot2.